@@ -18,10 +18,10 @@ class ContextExtension(ApiExtension):
     """
 
     conformance_classes: List[str] = attr.ib(
-        factory=lambda: ["https://api.stacspec.org/v1.0.0-beta.4/item-search/#context"]
+        factory=lambda: ["https://api.stacspec.org/v1.0.0-rc.1/item-search#context"]
     )
     schema_href: Optional[str] = attr.ib(
-        default="https://raw.githubusercontent.com/radiantearth/stac-api-spec/v1.0.0-beta.4/fragments/context/json-schema/schema.json"
+        default="https://raw.githubusercontent.com/radiantearth/stac-api-spec/v1.0.0-rc.1/fragments/context/json-schema/schema.json"
     )
 
     def register(self, app: FastAPI) -> None:
